aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/content_visibility.php
diff options
context:
space:
mode:
authorbrunoais <brunoaiss@gmail.com>2015-02-18 10:33:49 +0000
committerbrunoais <brunoaiss@gmail.com>2015-02-18 10:33:49 +0000
commit997b2297238cc4e1cee090de490c16d0bca7d478 (patch)
treeddd5621a23c7a7a34a1146e0c16edaa0da7f5f9a /phpBB/phpbb/content_visibility.php
parent088907fe8e18f87f7af3098041ac031501aa1f7f (diff)
downloadforums-997b2297238cc4e1cee090de490c16d0bca7d478.tar
forums-997b2297238cc4e1cee090de490c16d0bca7d478.tar.gz
forums-997b2297238cc4e1cee090de490c16d0bca7d478.tar.bz2
forums-997b2297238cc4e1cee090de490c16d0bca7d478.tar.xz
forums-997b2297238cc4e1cee090de490c16d0bca7d478.zip
[ticket/13631] Fix wrong variable in get_global_visibility_sql()'s event
I don't get this... I was positive I, at some point, had it right... I don't get what happened... PHPBB3-13631
Diffstat (limited to 'phpBB/phpbb/content_visibility.php')
-rw-r--r--phpBB/phpbb/content_visibility.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/phpBB/phpbb/content_visibility.php b/phpBB/phpbb/content_visibility.php
index c8516d6c85..88182d5d0c 100644
--- a/phpBB/phpbb/content_visibility.php
+++ b/phpBB/phpbb/content_visibility.php
@@ -252,7 +252,7 @@ class content_visibility
* @event core.phpbb_content_visibility_get_global_visibility_before
* @var array where_sqls The action the user tried to execute
* @var string mode Either "topic" or "post" depending on the query this is being used in
* @var array forum_ids Array of forum ids which the posts/topics are limited to
* @var string table_alias Table alias to prefix in SQL queries
* @var array approve_forums Array of forums where the user has m_approve permissions
* @var string visibility_sql_overwrite Forces the function to return an implosion of where_sqls (joined by "OR")
@@ -261,7 +261,7 @@ class content_visibility
$vars = array(
'where_sqls',
'mode',
- 'forum_ids',
+ 'exclude_forum_ids',
'table_alias',
'approve_forums',
'visibility_sql_overwrite',
@@ -252,7 +252,7 @@ class content_visibility
* @var array where_sqls The action the user tried to execute
* @var string mode Either "topic" or "post" depending on the query this is being used in
- * @var array forum_ids Array of forum ids which the posts/topics are limited to
+ * @var array exclude_forum_ids Array of forum ids which the posts/topics are limited to
* @var string table_alias Table alias to prefix in SQL queries
* @var array approve_forums Array of forums where the user has m_approve permissions